# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Group(pulumi.CustomResource):
    description: pulumi.Output[str]
    """
    The Description of the Project.
    """
    descriptor: pulumi.Output[str]
    """
    The identity (subject) descriptor of the Group.
    """
    display_name: pulumi.Output[str]
    """
    The name of a new Azure DevOps group that is not backed by an external provider. The `origin_id` and `mail` arguments cannot be used simultaneously with `display_name`.
    """
    domain: pulumi.Output[str]
    """
    This represents the name of the container of origin for a graph member.
    """
    mail: pulumi.Output[str]
    """
    The mail address as a reference to an existing group from an external AD or AAD backed provider. The `scope`, `origin_id` and `display_name` arguments cannot be used simultaneously with `mail`.
    """
    members: pulumi.Output[list]
    """
    > NOTE: It's possible to define group members both within the `Identities.Group` resource via the members block and by using the   `Identities.GroupMembership` resource. However it's not possible to use both methods to manage group members, since there'll be conflicts.
    """
    origin: pulumi.Output[str]
    """
    The type of source provider for the origin identifier (ex:AD, AAD, MSA)
    """
    origin_id: pulumi.Output[str]
    """
    The OriginID as a reference to a group from an external AD or AAD backed provider. The `scope`, `mail` and `display_name` arguments cannot be used simultaneously with `origin_id`.
    """
    principal_name: pulumi.Output[str]
    """
    This is the PrincipalName of this graph member from the source provider.
    """
    scope: pulumi.Output[str]
    """
    The scope of the group. A descriptor referencing the scope (collection, project) in which the group should be created. If omitted, will be created in the scope of the enclosing account or organization.x
    """
    subject_kind: pulumi.Output[str]
    """
    This field identifies the type of the graph subject (ex: Group, Scope, User).
    """
    url: pulumi.Output[str]
    """
    This url is the full route to the source resource of this graph subject.
    """
    def __init__(__self__, resource_name, opts=None, description=None, display_name=None, mail=None, members=None, origin_id=None, scope=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a group within Azure DevOps.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_azuredevops as azuredevops

        project = azuredevops.core.Project("project", project_name="Test Project")
        tf_project_readers = project.id.apply(lambda id: azuredevops.Identities.get_group(project_id=id,
            name="Readers"))
        tf_project_contributors = project.id.apply(lambda id: azuredevops.Identities.get_group(project_id=id,
            name="Contributors"))
        group = azuredevops.identities.Group("group",
            scope=project.id,
            display_name="Test group",
            description="Test description",
            members=[
                tf_project_readers.descriptor,
                tf_project_contributors.descriptor,
            ])
        ```

        ## Relevant Links

        * [Azure DevOps Service REST API 5.1 - Groups](https://docs.microsoft.com/en-us/rest/api/azure/devops/graph/groups?view=azure-devops-rest-5.1)

        ## PAT Permissions Required

        - **Project & Team**: Read, Write, & Manage

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The Description of the Project.
        :param pulumi.Input[str] display_name: The name of a new Azure DevOps group that is not backed by an external provider. The `origin_id` and `mail` arguments cannot be used simultaneously with `display_name`.
        :param pulumi.Input[str] mail: The mail address as a reference to an existing group from an external AD or AAD backed provider. The `scope`, `origin_id` and `display_name` arguments cannot be used simultaneously with `mail`.
        :param pulumi.Input[list] members: > NOTE: It's possible to define group members both within the `Identities.Group` resource via the members block and by using the   `Identities.GroupMembership` resource. However it's not possible to use both methods to manage group members, since there'll be conflicts.
        :param pulumi.Input[str] origin_id: The OriginID as a reference to a group from an external AD or AAD backed provider. The `scope`, `mail` and `display_name` arguments cannot be used simultaneously with `origin_id`.
        :param pulumi.Input[str] scope: The scope of the group. A descriptor referencing the scope (collection, project) in which the group should be created. If omitted, will be created in the scope of the enclosing account or organization.x
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['description'] = description
            __props__['display_name'] = display_name
            __props__['mail'] = mail
            __props__['members'] = members
            __props__['origin_id'] = origin_id
            __props__['scope'] = scope
            __props__['descriptor'] = None
            __props__['domain'] = None
            __props__['origin'] = None
            __props__['principal_name'] = None
            __props__['subject_kind'] = None
            __props__['url'] = None
        super(Group, __self__).__init__(
            'azuredevops:Identities/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, description=None, descriptor=None, display_name=None, domain=None, mail=None, members=None, origin=None, origin_id=None, principal_name=None, scope=None, subject_kind=None, url=None):
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The Description of the Project.
        :param pulumi.Input[str] descriptor: The identity (subject) descriptor of the Group.
        :param pulumi.Input[str] display_name: The name of a new Azure DevOps group that is not backed by an external provider. The `origin_id` and `mail` arguments cannot be used simultaneously with `display_name`.
        :param pulumi.Input[str] domain: This represents the name of the container of origin for a graph member.
        :param pulumi.Input[str] mail: The mail address as a reference to an existing group from an external AD or AAD backed provider. The `scope`, `origin_id` and `display_name` arguments cannot be used simultaneously with `mail`.
        :param pulumi.Input[list] members: > NOTE: It's possible to define group members both within the `Identities.Group` resource via the members block and by using the   `Identities.GroupMembership` resource. However it's not possible to use both methods to manage group members, since there'll be conflicts.
        :param pulumi.Input[str] origin: The type of source provider for the origin identifier (ex:AD, AAD, MSA)
        :param pulumi.Input[str] origin_id: The OriginID as a reference to a group from an external AD or AAD backed provider. The `scope`, `mail` and `display_name` arguments cannot be used simultaneously with `origin_id`.
        :param pulumi.Input[str] principal_name: This is the PrincipalName of this graph member from the source provider.
        :param pulumi.Input[str] scope: The scope of the group. A descriptor referencing the scope (collection, project) in which the group should be created. If omitted, will be created in the scope of the enclosing account or organization.x
        :param pulumi.Input[str] subject_kind: This field identifies the type of the graph subject (ex: Group, Scope, User).
        :param pulumi.Input[str] url: This url is the full route to the source resource of this graph subject.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["description"] = description
        __props__["descriptor"] = descriptor
        __props__["display_name"] = display_name
        __props__["domain"] = domain
        __props__["mail"] = mail
        __props__["members"] = members
        __props__["origin"] = origin
        __props__["origin_id"] = origin_id
        __props__["principal_name"] = principal_name
        __props__["scope"] = scope
        __props__["subject_kind"] = subject_kind
        __props__["url"] = url
        return Group(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

